use amadeus_macro::either;
use eframe::egui::Color32;

pub const PADDING: f32 = 6.0;
pub const TOP_PANEL_PADDING: f32 = 0.5;
pub const BOTTOM_PANEL_MAX_SIZE: f32 = 90.;
const WHITE: Color32 = Color32::from_rgb(255, 255, 255);
const BLACK: Color32 = Color32::from_rgb(0, 0, 0);
const CYAN: Color32 = Color32::from_rgb(0, 255, 255);
const RED: Color32 = Color32::from_rgb(255, 0, 0);

pub fn get_fill_color(dark_mode: bool) -> Color32 {
    let base_color = get_accent_color(dark_mode);
    if dark_mode {
        base_color
    } else {
        let factor = 0.69_f32;
        Color32::from_rgb(
            (base_color.r() as f32 * factor) as u8,
            (base_color.g() as f32 * factor) as u8,
            (base_color.b() as f32 * factor) as u8,
        )
    }
}

pub fn get_text_color(dark_mode: bool) -> Color32 {
    either!(dark_mode => WHITE; BLACK)
}

pub fn get_accent_color(dark_mode: bool) -> Color32 {
    either!(dark_mode => get_darker_color(CYAN); RED)
}

fn get_darker_color(color: Color32) -> Color32 {
    let factor = 0.69_f32;
    Color32::from_rgb(
        (color.r() as f32 * factor) as u8,
        (color.g() as f32 * factor) as u8,
        (color.b() as f32 * factor) as u8,
    )
}
